# Models and Fields

**NOTE:** This documentation is a stub. Documentation for this project is a work in progress!

## Introduction

## Saving Data As Hashes With HashModel

### What Does Redis Store?

## Saving Data With JSON With JsonModel

### What Does Redis Store?

## Primary Keys

### Why Primary Keys Matter to Redis OM

### Using the Default Primary Key

### Using a Custom Primary Key

## Meta Classes

## Subclassing Models

### Subclassing and Meta Objects

## Saving Models


